[gtk+] menu button: Revisit style class one more time



commit aa6e0ad3f2bd88a1117d663b4e148e72bd3ed074
Author: Matthias Clasen <mclasen redhat com>
Date:   Fri Oct 30 01:21:13 2015 -0400

    menu button: Revisit style class one more time
    
    Use .popup, which is already in use elsewhere, fits better with
    the other button differentiating style classes, and does not
    interfere with menus.

 gtk/gtkmenubutton.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/gtk/gtkmenubutton.c b/gtk/gtkmenubutton.c
index 54f895f..6d546b5 100644
--- a/gtk/gtkmenubutton.c
+++ b/gtk/gtkmenubutton.c
@@ -105,7 +105,7 @@
  * # CSS nodes
  *
  * GtkMenuButton has a single CSS node with name button. To differentiate
  * it from a plain #GtkButton, it gets the .menubutton style class.
  */
 
 #include "config.h"
@@ -673,7 +673,7 @@ gtk_menu_button_init (GtkMenuButton *menu_button)
   gtk_widget_set_sensitive (GTK_WIDGET (menu_button), FALSE);
 
   context = gtk_widget_get_style_context (GTK_WIDGET (menu_button));
-  gtk_style_context_add_class (context, "menubutton");
+  gtk_style_context_add_class (context, "popup");
 }
 
 /**
@@ -105,7 +105,7 @@
  *
  * GtkMenuButton has a single CSS node with name button. To differentiate
- * it from a plain #GtkButton, it gets the .menubutton style class.
+ * it from a plain #GtkButton, it gets the .popup style class.
  */
 


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]